==> libopenshot-0.3.2-x86_64-2ponce.txz: usr/doc/libopenshot-0.3.2/API/search/all_f.js <==
var searchData=
[
  ['m_5fage_0',['m_age',['../classKalmanTracker.html#a722d4c24d32a8a38b5014ff4c56985ec',1,'KalmanTracker']]],
  ['m_5fhit_5fstreak_1',['m_hit_streak',['../classKalmanTracker.html#a14cb803c9ce5606c0a1f2b4c20dab2cf',1,'KalmanTracker']]],
  ['m_5fhits_2',['m_hits',['../classKalmanTracker.html#a16991daf787fd1376adb7b1860c33217',1,'KalmanTracker']]],
  ['m_5fid_3',['m_id',['../classKalmanTracker.html#a7066baa82634353a6cbd3e1d5d1388b6',1,'KalmanTracker']]],
  ['m_5fmessage_4',['m_message',['../classopenshot_1_1ExceptionBase.html#a920db8ad9c6be8ed452fb702c1f28356',1,'openshot::ExceptionBase']]],
  ['m_5ftime_5fsince_5fupdate_5',['m_time_since_update',['../classKalmanTracker.html#adb37c4bf7be8b5f8319c7c7dbcb0c340',1,'KalmanTracker']]],
  ['mac_6',['INSTALL-MAC',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-MAC.html',1,'']]],
  ['mac_20build_20instructions_20libopenshot_7',['Mac Build Instructions (libopenshot)',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-MAC.html#autotoc_md70',1,'']]],
  ['mac_20build_20instructions_20libopenshot_20audio_8',['Mac Build Instructions (libopenshot-audio)',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-MAC.html#autotoc_md69',1,'']]],
  ['macos_9',['Building libopenshot for MacOS',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-MAC.html#autotoc_md43',1,'']]],
  ['magick_10',['Magick',['../namespaceMagick.html',1,'']]],
  ['magick2qimage_11',['Magick2QImage',['../namespaceopenshot.html#aad0c7aa8ef0c10d83c95f7228132ad10',1,'openshot']]],
  ['magick_5fdrawable_12',['MAGICK_DRAWABLE',['../MagickUtilities_8h.html#a5be0ddb640be0cef2444b03940a929e2',1,'MagickUtilities.h']]],
  ['magick_5fimage_5falpha_13',['MAGICK_IMAGE_ALPHA',['../MagickUtilities_8h.html#a7179da944023e09e9bc59dc9b24500dc',1,'MagickUtilities.h']]],
  ['magickutilities_2ecpp_14',['MagickUtilities.cpp',['../MagickUtilities_8cpp.html',1,'']]],
  ['magickutilities_2eh_15',['MagickUtilities.h',['../MagickUtilities_8h.html',1,'']]],
  ['major_16',['Major',['../structopenshot_1_1OpenShotVersion.html#a831db60eebb0bc99a3a4789205c2c0d1',1,'openshot::OpenShotVersion']]],
  ['makeup_5fgain_17',['makeup_gain',['../classopenshot_1_1Compressor.html#a530d953851ef4c5cbd7e7728afc271c0',1,'openshot::Compressor::makeup_gain'],['../classopenshot_1_1Expander.html#a69f8ae0277eb9eef688f9478a464440c',1,'openshot::Expander::makeup_gain']]],
  ['manual_18',['MANUAL',['../namespaceopenshot.html#a9aa98278ad9655bcbc58117d148e17cba81bab440a89cd1ea4ef25760ff9c4f95',1,'openshot']]],
  ['manual_20dependencies_19',['Manual Dependencies',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md99',1,'']]],
  ['mappedframe_20',['MappedFrame',['../structopenshot_1_1MappedFrame.html',1,'openshot']]],
  ['mask_21',['Mask',['../classopenshot_1_1Mask.html',1,'openshot::Mask'],['../classopenshot_1_1Mask.html#a209448a82e47f6ebf89f5b6fb8267dfa',1,'openshot::Mask::Mask()'],['../classopenshot_1_1Mask.html#afcab2a09178938b2d8fe5a446f9dcc32',1,'openshot::Mask::Mask(ReaderBase *mask_reader, Keyframe mask_brightness, Keyframe mask_contrast)']]],
  ['mask_2ecpp_22',['Mask.cpp',['../Mask_8cpp.html',1,'']]],
  ['mask_2eh_23',['Mask.h',['../Mask_8h.html',1,'']]],
  ['mat2qimage_24',['Mat2Qimage',['../classopenshot_1_1Frame.html#a0ee6f3feb141514ac8d2d7c7a92e0b8c',1,'openshot::Frame']]],
  ['matcheditems_25',['matchedItems',['../classSortTracker.html#ada8f58747a785c511212373f7ddceb23',1,'SortTracker']]],
  ['matchedpairs_26',['matchedPairs',['../classSortTracker.html#a73cc06448d5b837997f35e89d8693561',1,'SortTracker']]],
  ['max_5fbytes_27',['max_bytes',['../classopenshot_1_1CacheBase.html#ac6ddfaffe7fd677a6dce215d4da6bd9b',1,'openshot::CacheBase']]],
  ['max_5fcentroid_5fdist_5fnorm_28',['max_centroid_dist_norm',['../classSortTracker.html#a309859606b611c81689a5eb9ed22d61c',1,'SortTracker']]],
  ['max_5fframes_5fahead_29',['max_frames_ahead',['../classopenshot_1_1VideoCacheThread.html#a0fb7266db287bd39f54bd61635ec33da',1,'openshot::VideoCacheThread']]],
  ['max_5fsamples_30',['max_samples',['../structopenshot_1_1AudioWaveformData.html#a89fedebe66b965d626138a40cdc51f5a',1,'openshot::AudioWaveformData']]],
  ['max_5fsupported_5fheight_31',['MAX_SUPPORTED_HEIGHT',['../FFmpegReader_8cpp.html#a8b77caaef5b34ab4a755236dd68ffc45',1,'FFmpegReader.cpp']]],
  ['max_5fsupported_5fwidth_32',['MAX_SUPPORTED_WIDTH',['../FFmpegReader_8cpp.html#a25c971d31e73490a7c3918b0cb3b6ef4',1,'FFmpegReader.cpp']]],
  ['maxframes_33',['MaxFrames',['../classopenshot_1_1OutOfBoundsFrame.html#a21150ba2dcfa865ae15cc483552d2d5d',1,'openshot::OutOfBoundsFrame']]],
  ['maxpoints_34',['MaxPoints',['../classopenshot_1_1OutOfBoundsPoint.html#acfd35fb5e8f372157c7ab7e749cc6099',1,'openshot::OutOfBoundsPoint']]],
  ['metadata_35',['metadata',['../structopenshot_1_1ReaderInfo.html#a86995ddbffe7d0b9b62454c69a3f4590',1,'openshot::ReaderInfo::metadata'],['../structopenshot_1_1WriterInfo.html#a79569f30e0352a872a9e88cec5121b1b',1,'openshot::WriterInfo::metadata']]],
  ['min_5fframes_5fahead_36',['min_frames_ahead',['../classopenshot_1_1VideoCacheThread.html#abf521b833ed5a189c99869d506b40474',1,'openshot::VideoCacheThread']]],
  ['minor_37',['Minor',['../structopenshot_1_1OpenShotVersion.html#a01a031819377e99d3cfa117a7a18c450',1,'openshot::OpenShotVersion']]],
  ['mix_38',['mix',['../classopenshot_1_1Echo.html#a07e15b8a2770a9a1699abdc3d8598099',1,'openshot::Echo']]],
  ['mixed_5fdown_5finput_39',['mixed_down_input',['../classopenshot_1_1Compressor.html#aba137c0b124d9bce9d192778500f370a',1,'openshot::Compressor::mixed_down_input'],['../classopenshot_1_1Expander.html#ad4ea6a594e09aa6ccc7a3e49f0d773d6',1,'openshot::Expander::mixed_down_input']]],
  ['mixing_40',['mixing',['../classopenshot_1_1Clip.html#a2195326c44f40bb3f5c5f39b76904337',1,'openshot::Clip']]],
  ['mode_41',['Mode',['../classopenshot_1_1PlayerBase.html#ae3d68ba5efb7823e9435be0f12a8b3a4',1,'openshot::PlayerBase::Mode()'],['../classopenshot_1_1QtPlayer.html#adf51f50e9397da4c8ea196d99908571b',1,'openshot::QtPlayer::Mode()']]],
  ['mode_42',['mode',['../classopenshot_1_1PlayerBase.html#a5581a7f842895218d109094dd4751a36',1,'openshot::PlayerBase']]],
  ['more_43',['Want to Learn More?',['../index.html#autotoc_md4',1,'']]],
  ['movetofront_44',['MoveToFront',['../classopenshot_1_1CacheDisk.html#a1168df2b37f0085db86beb1415f241a0',1,'openshot::CacheDisk::MoveToFront()'],['../classopenshot_1_1CacheMemory.html#ab6ed345b88e08ec568190774d83ff350',1,'openshot::CacheMemory::MoveToFront()']]],
  ['msys2_20dependencies_45',['Install MSYS2 Dependencies',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md98',1,'']]],
  ['multiple_20graphics_20cards_46',['Multiple Graphics Cards',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2HW-ACCEL.html#autotoc_md12',1,'']]],
  ['multiplier_47',['multiplier',['../classopenshot_1_1Wave.html#aba59157f1e32781d7a05851fe6f517c2',1,'openshot::Wave']]],
  ['mutex_48',['mutex',['../classopenshot_1_1Robotization.html#a23bd82d1eb7d7189cc54f79e3a7bfa8f',1,'openshot::Robotization::mutex'],['../classopenshot_1_1Whisperization.html#a68ff60d2f1f8a67390fd9bebd2739f58',1,'openshot::Whisperization::mutex']]],
  ['mux_5fdict_49',['mux_dict',['../FFmpegWriter_8cpp.html#ae787a63bbef6bf3f8c406839bd1a1d68',1,'FFmpegWriter.cpp']]],
  ['my_5finput_5fbuffer_5fpadding_5fsize_50',['MY_INPUT_BUFFER_PADDING_SIZE',['../FFmpegUtilities_8h.html#ae8897fded3b2a5ff657584a50092969b',1,'FFmpegUtilities.h']]]
];

==> libopenshot-0.3.3-x86_64-1ponce.txz: usr/doc/libopenshot-0.3.3/API/search/all_f.js <==
var searchData=
[
  ['m_5fage_0',['m_age',['../classKalmanTracker.html#a722d4c24d32a8a38b5014ff4c56985ec',1,'KalmanTracker']]],
  ['m_5fhit_5fstreak_1',['m_hit_streak',['../classKalmanTracker.html#a14cb803c9ce5606c0a1f2b4c20dab2cf',1,'KalmanTracker']]],
  ['m_5fhits_2',['m_hits',['../classKalmanTracker.html#a16991daf787fd1376adb7b1860c33217',1,'KalmanTracker']]],
  ['m_5fid_3',['m_id',['../classKalmanTracker.html#a7066baa82634353a6cbd3e1d5d1388b6',1,'KalmanTracker']]],
  ['m_5fmessage_4',['m_message',['../classopenshot_1_1ExceptionBase.html#a920db8ad9c6be8ed452fb702c1f28356',1,'openshot::ExceptionBase']]],
  ['m_5ftime_5fsince_5fupdate_5',['m_time_since_update',['../classKalmanTracker.html#adb37c4bf7be8b5f8319c7c7dbcb0c340',1,'KalmanTracker']]],
  ['mac_6',['INSTALL-MAC',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-MAC.html',1,'']]],
  ['mac_20build_20instructions_20libopenshot_7',['Mac Build Instructions (libopenshot)',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-MAC.html#autotoc_md70',1,'']]],
  ['mac_20build_20instructions_20libopenshot_20audio_8',['Mac Build Instructions (libopenshot-audio)',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-MAC.html#autotoc_md69',1,'']]],
  ['macos_9',['Building libopenshot for MacOS',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-MAC.html#autotoc_md43',1,'']]],
  ['magick_10',['Magick',['../namespaceMagick.html',1,'']]],
  ['magick2qimage_11',['Magick2QImage',['../namespaceopenshot.html#aad0c7aa8ef0c10d83c95f7228132ad10',1,'openshot']]],
  ['magick_5fdrawable_12',['MAGICK_DRAWABLE',['../MagickUtilities_8h.html#a5be0ddb640be0cef2444b03940a929e2',1,'MagickUtilities.h']]],
  ['magick_5fimage_5falpha_13',['MAGICK_IMAGE_ALPHA',['../MagickUtilities_8h.html#a7179da944023e09e9bc59dc9b24500dc',1,'MagickUtilities.h']]],
  ['magickutilities_2ecpp_14',['MagickUtilities.cpp',['../MagickUtilities_8cpp.html',1,'']]],
  ['magickutilities_2eh_15',['MagickUtilities.h',['../MagickUtilities_8h.html',1,'']]],
  ['major_16',['Major',['../structopenshot_1_1OpenShotVersion.html#a831db60eebb0bc99a3a4789205c2c0d1',1,'openshot::OpenShotVersion']]],
  ['makeup_5fgain_17',['makeup_gain',['../classopenshot_1_1Compressor.html#a530d953851ef4c5cbd7e7728afc271c0',1,'openshot::Compressor::makeup_gain'],['../classopenshot_1_1Expander.html#a69f8ae0277eb9eef688f9478a464440c',1,'openshot::Expander::makeup_gain']]],
  ['manual_18',['MANUAL',['../namespaceopenshot.html#a9aa98278ad9655bcbc58117d148e17cba81bab440a89cd1ea4ef25760ff9c4f95',1,'openshot']]],
  ['manual_20dependencies_19',['Manual Dependencies',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md99',1,'']]],
  ['mappedframe_20',['MappedFrame',['../structopenshot_1_1MappedFrame.html',1,'openshot']]],
  ['mask_21',['Mask',['../classopenshot_1_1Mask.html',1,'openshot::Mask'],['../classopenshot_1_1Mask.html#a209448a82e47f6ebf89f5b6fb8267dfa',1,'openshot::Mask::Mask()'],['../classopenshot_1_1Mask.html#afcab2a09178938b2d8fe5a446f9dcc32',1,'openshot::Mask::Mask(ReaderBase *mask_reader, Keyframe mask_brightness, Keyframe mask_contrast)']]],
  ['mask_2ecpp_22',['Mask.cpp',['../Mask_8cpp.html',1,'']]],
  ['mask_2eh_23',['Mask.h',['../Mask_8h.html',1,'']]],
  ['mat2qimage_24',['Mat2Qimage',['../classopenshot_1_1Frame.html#a0ee6f3feb141514ac8d2d7c7a92e0b8c',1,'openshot::Frame']]],
  ['matcheditems_25',['matchedItems',['../classSortTracker.html#ada8f58747a785c511212373f7ddceb23',1,'SortTracker']]],
  ['matchedpairs_26',['matchedPairs',['../classSortTracker.html#a73cc06448d5b837997f35e89d8693561',1,'SortTracker']]],
  ['max_5fbytes_27',['max_bytes',['../classopenshot_1_1CacheBase.html#ac6ddfaffe7fd677a6dce215d4da6bd9b',1,'openshot::CacheBase']]],
  ['max_5fcentroid_5fdist_5fnorm_28',['max_centroid_dist_norm',['../classSortTracker.html#a309859606b611c81689a5eb9ed22d61c',1,'SortTracker']]],
  ['max_5fframes_5fahead_29',['max_frames_ahead',['../classopenshot_1_1VideoCacheThread.html#a0fb7266db287bd39f54bd61635ec33da',1,'openshot::VideoCacheThread']]],
  ['max_5fsamples_30',['max_samples',['../structopenshot_1_1AudioWaveformData.html#a89fedebe66b965d626138a40cdc51f5a',1,'openshot::AudioWaveformData']]],
  ['max_5fsupported_5fheight_31',['MAX_SUPPORTED_HEIGHT',['../FFmpegReader_8cpp.html#a8b77caaef5b34ab4a755236dd68ffc45',1,'FFmpegReader.cpp']]],
  ['max_5fsupported_5fwidth_32',['MAX_SUPPORTED_WIDTH',['../FFmpegReader_8cpp.html#a25c971d31e73490a7c3918b0cb3b6ef4',1,'FFmpegReader.cpp']]],
  ['maxframes_33',['MaxFrames',['../classopenshot_1_1OutOfBoundsFrame.html#a21150ba2dcfa865ae15cc483552d2d5d',1,'openshot::OutOfBoundsFrame']]],
  ['maxpoints_34',['MaxPoints',['../classopenshot_1_1OutOfBoundsPoint.html#acfd35fb5e8f372157c7ab7e749cc6099',1,'openshot::OutOfBoundsPoint']]],
  ['metadata_35',['metadata',['../structopenshot_1_1ReaderInfo.html#a86995ddbffe7d0b9b62454c69a3f4590',1,'openshot::ReaderInfo::metadata'],['../structopenshot_1_1WriterInfo.html#a79569f30e0352a872a9e88cec5121b1b',1,'openshot::WriterInfo::metadata']]],
  ['min_5fframes_5fahead_36',['min_frames_ahead',['../classopenshot_1_1VideoCacheThread.html#abf521b833ed5a189c99869d506b40474',1,'openshot::VideoCacheThread']]],
  ['minor_37',['Minor',['../structopenshot_1_1OpenShotVersion.html#a01a031819377e99d3cfa117a7a18c450',1,'openshot::OpenShotVersion']]],
  ['mix_38',['mix',['../classopenshot_1_1Echo.html#a07e15b8a2770a9a1699abdc3d8598099',1,'openshot::Echo']]],
  ['mixed_5fdown_5finput_39',['mixed_down_input',['../classopenshot_1_1Compressor.html#aba137c0b124d9bce9d192778500f370a',1,'openshot::Compressor::mixed_down_input'],['../classopenshot_1_1Expander.html#ad4ea6a594e09aa6ccc7a3e49f0d773d6',1,'openshot::Expander::mixed_down_input']]],
  ['mixing_40',['mixing',['../classopenshot_1_1Clip.html#a2195326c44f40bb3f5c5f39b76904337',1,'openshot::Clip']]],
  ['mode_41',['Mode',['../classopenshot_1_1PlayerBase.html#ae3d68ba5efb7823e9435be0f12a8b3a4',1,'openshot::PlayerBase::Mode()'],['../classopenshot_1_1QtPlayer.html#adf51f50e9397da4c8ea196d99908571b',1,'openshot::QtPlayer::Mode()']]],
  ['mode_42',['mode',['../classopenshot_1_1PlayerBase.html#a5581a7f842895218d109094dd4751a36',1,'openshot::PlayerBase']]],
  ['more_43',['Want to Learn More?',['../index.html#autotoc_md4',1,'']]],
  ['movetofront_44',['MoveToFront',['../classopenshot_1_1CacheDisk.html#a1168df2b37f0085db86beb1415f241a0',1,'openshot::CacheDisk::MoveToFront()'],['../classopenshot_1_1CacheMemory.html#ab6ed345b88e08ec568190774d83ff350',1,'openshot::CacheMemory::MoveToFront()']]],
  ['msys2_20dependencies_45',['Install MSYS2 Dependencies',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md98',1,'']]],
  ['multiple_20graphics_20cards_46',['Multiple Graphics Cards',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2HW-ACCEL.html#autotoc_md12',1,'']]],
  ['multiplier_47',['multiplier',['../classopenshot_1_1Wave.html#aba59157f1e32781d7a05851fe6f517c2',1,'openshot::Wave']]],
  ['mutex_48',['mutex',['../classopenshot_1_1Robotization.html#a23bd82d1eb7d7189cc54f79e3a7bfa8f',1,'openshot::Robotization::mutex'],['../classopenshot_1_1Whisperization.html#a68ff60d2f1f8a67390fd9bebd2739f58',1,'openshot::Whisperization::mutex']]],
  ['mux_5fdict_49',['mux_dict',['../FFmpegWriter_8cpp.html#ae787a63bbef6bf3f8c406839bd1a1d68',1,'FFmpegWriter.cpp']]],
  ['my_5finput_5fbuffer_5fpadding_5fsize_50',['MY_INPUT_BUFFER_PADDING_SIZE',['../FFmpegUtilities_8h.html#ae8897fded3b2a5ff657584a50092969b',1,'FFmpegUtilities.h']]]
];
